@@ -190,7 +190,8 @@ class LuxAI2022(ParallelEnv):
                 raise ValueError(f"Invalid player {k}")
             if "faction" in a and "bid" in a:
                 if a["faction"] not in [e.name for e in FactionTypes]:
-                    failed_agents[k] = False
+                    self._log(f"{k} initialized with invalid faction name {a['faction']}")
+                    failed_agents[k] = True
                     continue
                 self.state.teams[k] = Team(
                     team_id=self.agent_name_mapping[k], agent=k, faction=FactionTypes[a["faction"]]
@@ -610,7 +611,7 @@ class LuxAI2022(ParallelEnv):
         self.env_steps += 1
         self.state.env_steps += 1
         env_done = self.state.real_env_steps >= self.state.env_cfg.max_episode_length
-        env_done = failed_agents["player_0"] or failed_agents["player_1"] # env is done if any agent fails.
+        env_done = env_done or failed_agents["player_0"] or failed_agents["player_1"] # env is done if any agent fails.
         dones = {agent: env_done or failed_agents[agent] for agent in self.agents}
 
         # generate observations
